@@ -10,13 +10,18 @@ from django.shortcuts import get_object_or_404, render, redirect
 from django.urls import reverse, re_path
 from django.utils.text import capfirst
 from django.utils.timezone import template_localtime
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.utils.encoding import force_str
 from django.utils.formats import localize
 from reversion.errors import RevertError
 from reversion.models import Version
 from reversion.revisions import is_active, register, is_registered, set_comment, create_revision, set_user
-from reversion.views import _RollBackRevisionView
+
+
+class _RollBackRevisionView(Exception):
+
+    def __init__(self, response):
+        self.response = response
 
 
 class VersionAdmin(admin.ModelAdmin):
