@@ -3,12 +3,6 @@ from functools import wraps
 from reversion.revisions import create_revision as create_revision_base, set_user, get_user
 
 
-class _RollBackRevisionView(Exception):
-
-    def __init__(self, response):
-        self.response = response
-
-
 def _request_creates_revision(request):
     return request.method not in ("OPTIONS", "GET", "HEAD")
 
@@ -30,17 +24,11 @@ def create_revision(manage_manually=False, using=None, atomic=True, request_crea
         @wraps(func)
         def do_revision_view(request, *args, **kwargs):
             if request_creates_revision(request):
-                try:
-                    with create_revision_base(manage_manually=manage_manually, using=using, atomic=atomic):
-                        response = func(request, *args, **kwargs)
-                        # Check for an error response.
-                        if response.status_code >= 400:
-                            raise _RollBackRevisionView(response)
-                        # Otherwise, we're good.
-                        _set_user_from_request(request)
-                        return response
-                except _RollBackRevisionView as ex:
-                    return ex.response
+                with create_revision_base(manage_manually=manage_manually, using=using, atomic=atomic):
+                    response = func(request, *args, **kwargs)
+                    # Otherwise, we're good.
+                    _set_user_from_request(request)
+                    return response
             return func(request, *args, **kwargs)
         return do_revision_view
     return decorator
